A synthetic discrete choice dataset with each observation having two generic alternatives composed of two attributes (travel time and toll). The data are panel in nature (as opposed to cross-sectional) with 8 choice tasks per decision maker.
Usage
data(choicedata)
Arguments
Details
These choice data were synthetically derived to be used in generating examples of how RSGHB is used to estimate discrete choice models.